@@ -40,6 +40,8 @@
 #include "sim.h"
 #include "smsutil.h"
 
+#define uninitialized_var(x) x = x
+
 #define SMS_MANAGER_INTERFACE "org.ofono.SmsManager"
 
 #define SMS_MANAGER_FLAG_CACHED 0x1
@@ -314,7 +316,6 @@ static gboolean tx_next(gpointer user_data)
 	time_t ts;
 	gboolean send_mms = FALSE;
 	struct pending_pdu *pdu = g_queue_peek_head(sms->txq);
-	char *encoded_pdu;
 	struct ofono_error error;
 
 	error.type = OFONO_ERROR_TYPE_NO_ERROR;
@@ -523,11 +524,14 @@ static void sms_dispatch(struct ofono_modem *modem, GSList *sms_list)
 {
 	GSList *l;
 	const struct sms *sms;
-	enum sms_charset old_charset;
+	enum sms_charset uninitialized_var(old_charset);
 	enum sms_class cls;
 	int srcport = -1;
 	int dstport = -1;
 
+	if (sms_list == NULL)
+		return;
+
 	/* Qutoting 23.040: The TP elements in the SMS‑SUBMIT PDU, apart from
 	 * TP‑MR, TP-SRR, TP‑UDL and TP‑UD, should remain unchanged for each
 	 * SM which forms part of a concatenated SM, otherwise this may lead
